/**
 *  Copyright 2012 Wordnik, Inc.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package com.wordnik.api.client.api

import com.wordnik.api.client.model._

import org.codehaus.jackson.map.DeserializationConfig.Feature
import org.codehaus.jackson.map.ObjectMapper
import org.codehaus.jackson.`type`.TypeReference
import com.wordnik.swagger.runtime.annotations._
import com.wordnik.swagger.runtime.common._
import com.wordnik.swagger.runtime.exception._

import java.io.IOException

import scala.collection.mutable._
import scala.collection.JavaConversions._


/**
 *
 * NOTE: This class is auto generated by the swagger code generator program. Do not edit the class manually.
 * @author tony
 *
 */
object AccountAPI {

    /**
     * Authenticates a User
     *
     * 
     * 
     * @param username  A confirmed Wordnik username
 @param password  The user's password
 
     * @return AuthenticationToken {@link AuthenticationToken} 
     * @throws APIException 403 - Account not available. 404 - User not found. 
     */
     @MethodArgumentNames(value="username, password") 
     @throws(classOf[APIException])
     def authenticate(username:String, password:String) :AuthenticationToken = {

        //parse inputs
        var resourcePath = "/account.{format}/authenticate/{username}".replace("{format}","json")
        val method = "GET";
        var queryParams = new HashMap[String, String]
        var headerParams = new HashMap[String, String]

        if(null != password) {
             queryParams += "password" -> APIInvoker.toPathValue(password)
        }

        if(null != username) {
            resourcePath = resourcePath.replace("{username}", APIInvoker.toPathValue(username))
        }
        
    
        //make the API Call
        val response = APIInvoker.getApiInvoker.invokeAPI(resourcePath, method, queryParams, null, headerParams)
        if(null == response || response.length() == 0){
            null
        }        //create output objects if the response has more than one object
        val responseObject = APIInvoker.deserialize(response, classOf[AuthenticationToken]).asInstanceOf[AuthenticationToken]
        responseObject        
                
     }
    /**
     * Authenticates a user
     *
     * 
     * 
     * @param username  A confirmed Wordnik username
 @param postData  The user's password
 
     * @return AuthenticationToken {@link AuthenticationToken} 
     * @throws APIException 403 - Account not available. 404 - User not found. 
     */
     @MethodArgumentNames(value="username, postData") 
     @throws(classOf[APIException])
     def authenticatePost(username:String, postData:String) :AuthenticationToken = {

        //parse inputs
        var resourcePath = "/account.{format}/authenticate/{username}".replace("{format}","json")
        val method = "POST";
        var queryParams = new HashMap[String, String]
        var headerParams = new HashMap[String, String]

        if(null != username) {
            resourcePath = resourcePath.replace("{username}", APIInvoker.toPathValue(username))
        }
        
    
        //make the API Call
        val response = APIInvoker.getApiInvoker.invokeAPI(resourcePath, method, queryParams, postData, headerParams)
        if(null == response || response.length() == 0){
            null
        }        //create output objects if the response has more than one object
        val responseObject = APIInvoker.deserialize(response, classOf[AuthenticationToken]).asInstanceOf[AuthenticationToken]
        responseObject        
                
     }
    /**
     * Fetches WordList objects for the logged-in user.
     *
     * 
     * 
     * @param api_key  
 @param auth_token  auth_token of logged-in user
 @param skip  Results to skip
 @param limit  Maximum number of results to return
 
     * @return List[WordList] {@link WordList} 
     * @throws APIException 403 - Not authenticated. 404 - User account not found. 
     */
     @MethodArgumentNames(value="api_key, auth_token, skip, limit") 
     @throws(classOf[APIException])
     def getWordListsForCurrentUser(api_key:String, auth_token:String, skip:String, limit:String) :List[WordList] = {

        //parse inputs
        var resourcePath = "/account.{format}/wordLists".replace("{format}","json")
        val method = "GET";
        var queryParams = new HashMap[String, String]
        var headerParams = new HashMap[String, String]

        if(null != skip) {
             queryParams += "skip" -> APIInvoker.toPathValue(skip)
        }
        if(null != limit) {
             queryParams += "limit" -> APIInvoker.toPathValue(limit)
        }

        if(null != api_key) {
             headerParams += "api_key" -> APIInvoker.toPathValue(api_key)
        }
        if(null != auth_token) {
             headerParams += "auth_token" -> APIInvoker.toPathValue(auth_token)
        }

        
    
        //make the API Call
        val response = APIInvoker.getApiInvoker.invokeAPI(resourcePath, method, queryParams, null, headerParams)
        if(null == response || response.length() == 0){
            null
        }        
        val typeRef = new TypeReference[Array[WordList]] {}
        try {
            val responseObject = APIInvoker.mapper.readValue(response, typeRef).asInstanceOf[Array[WordList]]
            responseObject.toList
        } catch { 
        	case ioe:IOException => {
	            val args = Array(response, typeRef.toString())
	            throw new APIException(APIExceptionCodes.ERROR_CONVERTING_JSON_TO_JAVA, args, "Error in converting response json value to java object : " + ioe.getMessage(), ioe)
	        }
	        case _ => throw new APIException(APIExceptionCodes.ERROR_CONVERTING_JSON_TO_JAVA, "Error in converting response json value to java object")
        }                        
     }
    /**
     * Returns usage statistics for the API account.
     *
     * 
     * 
     * @param api_key  
 
     * @return ApiTokenStatus {@link ApiTokenStatus} 
     * @throws APIException 400 - No token supplied. 404 - No API account with supplied token. 
     */
     @MethodArgumentNames(value="api_key") 
     @throws(classOf[APIException])
     def getApiTokenStatus(api_key:String) :ApiTokenStatus = {

        //parse inputs
        var resourcePath = "/account.{format}/apiTokenStatus".replace("{format}","json")
        val method = "GET";
        var queryParams = new HashMap[String, String]
        var headerParams = new HashMap[String, String]

        if(null != api_key) {
             headerParams += "api_key" -> APIInvoker.toPathValue(api_key)
        }

        
    
        //make the API Call
        val response = APIInvoker.getApiInvoker.invokeAPI(resourcePath, method, queryParams, null, headerParams)
        if(null == response || response.length() == 0){
            null
        }        //create output objects if the response has more than one object
        val responseObject = APIInvoker.deserialize(response, classOf[ApiTokenStatus]).asInstanceOf[ApiTokenStatus]
        responseObject        
                
     }
    /**
     * Returns the logged-in User
     *
     * Requires a valid auth_token to be set.
     * 
     * @param api_key  
 @param auth_token  The auth token of the logged-in user, obtained by calling /account.{format}/authenticate/{username} (described above)
 
     * @return User {@link User} 
     * @throws APIException 403 - Not logged in. 404 - User not found. 
     */
     @MethodArgumentNames(value="api_key, auth_token") 
     @throws(classOf[APIException])
     def getLoggedInUser(api_key:String, auth_token:String) :User = {

        //parse inputs
        var resourcePath = "/account.{format}/user".replace("{format}","json")
        val method = "GET";
        var queryParams = new HashMap[String, String]
        var headerParams = new HashMap[String, String]

        if(null != api_key) {
             headerParams += "api_key" -> APIInvoker.toPathValue(api_key)
        }
        if(null != auth_token) {
             headerParams += "auth_token" -> APIInvoker.toPathValue(auth_token)
        }

        
    
        //make the API Call
        val response = APIInvoker.getApiInvoker.invokeAPI(resourcePath, method, queryParams, null, headerParams)
        if(null == response || response.length() == 0){
            null
        }        //create output objects if the response has more than one object
        val responseObject = APIInvoker.deserialize(response, classOf[User]).asInstanceOf[User]
        responseObject        
                
     }

}